Struct
QmiIndicationImsdcmPdpActivateOutput
since: 1.37
Description [src]
struct QmiIndicationImsdcmPdpActivateOutput {
/* No available fields */
}
The QmiIndicationImsdcmPdpActivateOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.37
Instance methods
qmi_indication_imsdcm_pdp_activate_output_get_address_info
Get the ‘Address Info’ field from self.
since: 1.37
qmi_indication_imsdcm_pdp_activate_output_get_instance_id
Get the ‘Instance Id’ field from self.
since: 1.37
qmi_indication_imsdcm_pdp_activate_output_get_pdp_request_sequence_number
Get the ‘PDP Request Sequence Number’ field from self.
since: 1.37
qmi_indication_imsdcm_pdp_activate_output_get_result
Get the result of the QMI operation.
since: 1.37
qmi_indication_imsdcm_pdp_activate_output_ref
Atomically increments the reference count of self by one.
since: 1.37
qmi_indication_imsdcm_pdp_activate_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.37